@@ -28,3 +28,11 @@ from fastapi_mvc.generators.base import Generator
 from fastapi_mvc.generators.project import ProjectGenerator
 from fastapi_mvc.generators.controller import ControllerGenerator
 from fastapi_mvc.generators.generator import GeneratorGenerator
+
+
+__all__ = (
+    "Generator",
+    "ProjectGenerator",
+    "ControllerGenerator",
+    "GeneratorGenerator",
+)
